import { transformError as sdkTransformError } from '@wix/sdk-runtime/transform-error';
import { renameKeysFromSDKRequestToRESTRequest, renameKeysFromRESTResponseToSDKResponse, } from '@wix/sdk-runtime/rename-all-nested-keys';
import * as ambassadorWixSiteActionsV1SiteActions from './site-actions-v1-site-actions-site-actions.http.js';
/**
 * Publishes a site.
 *
 * Publishing a site makes any changes previously saved on the site available on the internet.
 * After publishing, changes to your site appear in the [site's history](https://support.wix.com/en/article/viewing-and-managing-your-site-history).
 *
 * When you call this API, you must pass a header called `wix-site-id` whose value is the ID of the site you want to publish. Learn more about
 * working with [API keys and site IDs](https://dev.wix.com/docs/rest/articles/getting-started/api-keys#create-and-use-api-keys).
 *
 * >**Important:** This call requires an account level API key and cannot be authenticated with the standard authorization header.
 * @public
 * @permissionId METASITE.UPDATE
 * @fqn wix.site.v1.SitePublisher.PublishSite
 */
export async function publishSite() {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[0];
    const payload = renameKeysFromSDKRequestToRESTRequest({});
    const reqOpts = ambassadorWixSiteActionsV1SiteActions.publishSite(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {},
            singleArgumentUnchanged: false,
        }, []);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
/**
 * Duplicates a site with a new site name.
 *
 * > **Note:** When you duplicate a site, some business-related content such as store orders, contacts, invoices, and 3rd-party app settings are not be included.
 * > The duplicated site won’t have a domain or any Premium capabilities.
 *
 * Any installed apps that can be used only on sites with a Premium Plan, will be copied to the duplicated site and
 * will appear unactivated. Once the site is upgraded, the app will be available for use.
 *
 * > **Important:** This call requires an account level API key and cannot be authenticated with the standard authorization header.
 * @param sourceSiteId - ID of the site to duplicated.
 * @public
 * @documentationMaturity preview
 * @requiredField options
 * @requiredField options.siteDisplayName
 * @requiredField sourceSiteId
 * @permissionId my-account.duplicate-site
 * @fqn com.wix.site.actions.SiteActionsService.DuplicateSite
 */
export async function duplicateSite(sourceSiteId, options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        sourceSiteId: sourceSiteId,
        siteDisplayName: options?.siteDisplayName,
    });
    const reqOpts = ambassadorWixSiteActionsV1SiteActions.duplicateSite(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(result.data);
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                sourceSiteId: '$[0]',
                siteDisplayName: '$[1].siteDisplayName',
            },
            singleArgumentUnchanged: false,
        }, ['sourceSiteId', 'options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
/**
 * This endpoint enables you to delete multiple sites.
 *
 * This is not a permanent delete. Sites are moved to the trash bin and can be restored through site collaborators.
 *
 * Learn more about [deleting multiple sites](https://support.wix.com/en/article/moving-a-site-to-trash).
 *
 * > **Important:** This call requires an account level API key and cannot be authenticated with the standard authorization header.
 * @param ids - Site IDs.
 *
 * Min: 1 site ID <br>
 * Max: 20 site IDs
 * @public
 * @documentationMaturity preview
 * @requiredField ids
 * @permissionId my-account.delete-site
 * @fqn com.wix.site.actions.SiteActionsService.BulkDeleteSite
 */
export async function bulkDeleteSite(ids) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = renameKeysFromSDKRequestToRESTRequest({ ids: ids });
    const reqOpts = ambassadorWixSiteActionsV1SiteActions.bulkDeleteSite(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(result.data);
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { ids: '$[0]' },
            singleArgumentUnchanged: false,
        }, ['ids']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
//# sourceMappingURL=site-actions-v1-site-actions-site-actions.universal.js.map